ComplexRugRat

Struct ComplexRugRat 

pub struct ComplexRugRat {
    pub r: Rational,
    pub i: Rational,
}
A complex number made of a real part and an imaginary part, both of which are rug::Rationals. Requires the rug feature.

Fields

r: Rational

The real part

i: Rational

The imaginary part

Implementations

Source

impl ComplexRugRat

pub fn conjugate(&self) -> Self

Returns the complex conjugate of this number