pub enum MathError {
UndefinedVariable {
name: String,
},
UndefinedFunction {
name: String,
},
IncorrectArguments,
DivideByZero,
NaN,
CmpError,
Unimplemented {
op: String,
num_type: String,
},
Other,
}Expand description
An error that can occur while evaluating an expression
Variants
UndefinedVariable
A variable that was not defined in the context was referenced
UndefinedFunction
A function that was not defined in the context was referenced
IncorrectArguments
A function was given arguments in an incorrect form
DivideByZero
Attempted to divide by zero
NaN
A NaN value was used in a way that is not possible
CmpError
Tried to compare a value that can’t be compared (eg NaN, Infinity, etc.)
Unimplemented
Attempted an operation on a Number that wasn’t implemented for that type
Fields
Other
Another type of Error occurred.