Module mexprp::expr
[−]
[src]
Contains expressions and terms
Structs
| Expression |
The main Expression struct. Contains only a Term and a String representing the original equation requesting to be parsed. Will contain intermediate representations in the future. To just compile to a pure representation of an expression, without anything extra, use Term. |
Enums
| Term |
The main representation of parsed equations. It is an operand that can contain an operation between more of itself. This form is necessary for the equation to be evaluated. |
Type Definitions
| Calculation |
The result of an evaluation (Result<f64, MathError>) |