pub struct ComplexRugRat {
pub r: Rational,
pub i: Rational,
}Expand description
A complex number made of a real part and an imaginary part, both of which are rug::Rationals.
Requires the rug feature.
Fields
r: RationalThe real part
i: RationalThe imaginary part
Implementations
Sourceimpl ComplexRugRat
impl ComplexRugRat